party-notes
===========
This module adds a notes page to the party type.
You can add any text to a party.

Install
=======

pip install mds-party-notes

Requires
========
- Tryton 7.0

Changes
=======

*7.0.1 - 01.12.2023*

- compatibility to Tryton 7.0
